#!/usr/bin/env python
import os
import shutil
import coloredlogs, logging
logger = logging.getLogger(__name__)
coloredlogs.install(level='DEBUG', logger=logger)



class LocalFilesHelper:

    def __init__(self,directory_path):
        self.dirname = directory_path
        if not os.path.exists(directory_path):
            os.makedirs(directory_path)


    def get_files_from_directory(self):
        '''
            Utility function to get bucket and key from a S3 path
            PARAMETERS:
                path (string): local path
            OUTPUT:
                bucket (string): bucket in which the s3 path is
                key (string): s3 path without the bucket.
            USAGE:
                list_keys('s3_bucket/s3_path/file.txt')
        '''
        # Get list of files
        filepaths = []
        for basename in os.listdir(self.dirname):
            filename = os.path.join(self.dirname, basename)
            if os.path.isfile(filename):
                filepaths.append(filename)

        return filepaths
    
    def create_dest_path_for_file(self,source_file_path):
        if '/' in source_file_path :
            file_name = source_file_path.split('/')[-1]
            if '.' in file_name:
                return self.dirname + '/' + file_name
            else:
                logger.warning('Skip folder: '+str(source_file_path))
                return None
        else:
            logging.error('bad file: ',source_file_path)
            return None

    def create_pathfile_for_dict(self,source_file_dict):
        filepath =  source_file_dict['S3path']
        return self.create_dest_path_for_file(filepath)


    def create_subdirectory_for_file(self,file_path):
        string_split = file_path.split('/')[:-1]
        subdirectory_path = '/'.join(string_split)
        if not os.path.exists(subdirectory_path):
            os.makedirs(subdirectory_path)


    def replace_main_foldername(self,path):
        if '/' in path:
            new_path = path.split('/')
            new_path[0] = self.dirname
            return '/'.join(new_path)

    def move_file(self,source_file):
        '''
            Utility function to ove files to this folder
            PARAMETERS:
                path (string): local path
            OUTPUT:
            USAGE:
                move_file('s3_bucket/s3_path/file.txt')
        '''
        if '/' in source_file:
            file_name = source_file.split('/')[-1]
        dest_file = self.dirname +'/' + file_name
        try:
            shutil.move(source_file, dest_file) 
        except Exception as e:
            print(e)
        

        